Documentation
¶
Overview ¶
Package model contains struct for HTTP request bodies and their JSON definitions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccessRequest ¶
type AccessRequest struct {
// Domain represents the domain field of the request.
Domain string `json:"domain"`
// Role represents the role field of the request.
Role string `json:"role"`
// ProxyForPrincipal represents the ProxyForPrincipal field of the request.
ProxyForPrincipal string `json:"proxy_for_principal"`
// Expiry represents the Expiry field of the request.
Expiry int64 `json:"expiry"`
}
AccessRequest represents the request information to retrieve the access token.
type AccessResponse ¶
type AccessResponse = service.AccessTokenResponse
AccessResponse represents the AccessTokenResponse from postAccessTokenRequest.
type NTokenResponse ¶
type NTokenResponse struct {
// NToken represents the N-token generated.
NToken string `json:"token"`
}
NTokenResponse represents the response information of get N-token request.
type RoleRequest ¶
type RoleRequest struct {
// Domain represents the domain field of the request.
Domain string `json:"domain"`
// Role represents the role field of the request.
Role string `json:"role"`
// ProxyForPrincipal represents the ProxyForPrincipal field of the request.
ProxyForPrincipal string `json:"proxy_for_principal"`
// MinExpiry represents the MinExpiry field of the request.
MinExpiry int64 `json:"min_expiry"`
// MaxExpiry represents the MaxExpiry field of the request.
MaxExpiry int64 `json:"max_expiry"`
}
RoleRequest represents the request information to get the role token.
type RoleResponse ¶
RoleResponse represents the basic information of the role token.
type SvcCertResponse ¶
type SvcCertResponse struct {
Cert []byte `json:"cert"`
}
SvcCertResponse represents the response information of get svccert request.
Click to show internal directories.
Click to hide internal directories.